@@ -41,7 +41,7 @@ class TestConfigurationList(TestConfigurations):
     }
 
     columns = database_configurations.ListDatabaseConfigurations.columns
-    values = ('c-123', 'test_config', '', 'mysql', '5.6')
+    values = ('c-123', 'test_config', '', 'mysql', '5.6', "5.7.29")
 
     def setUp(self):
         super(TestConfigurationList, self).setUp()
@@ -60,7 +60,7 @@ class TestConfigurationList(TestConfigurations):
 
 class TestConfigurationShow(TestConfigurations):
 
-    values = ('2015-05-16T10:24:28', 'mysql', '5.6', '', 'c-123',
+    values = ('2015-05-16T10:24:28', 'mysql', '5.6', '5.7.29', '', 'c-123',
               'test_config', '2015-05-16T10:24:29', '{"max_connections": 5}')
 
     def setUp(self):
@@ -73,6 +73,7 @@ class TestConfigurationShow(TestConfigurations):
             'created',
             'datastore_name',
             'datastore_version_name',
+            'datastore_version_number',
             'description',
             'id',
             'name',
@@ -205,7 +206,7 @@ class TestDatabaseConfigurationDelete(TestConfigurations):
 
 class TestConfigurationCreate(TestConfigurations):
 
-    values = ('2015-05-16T10:24:28', 'mysql', '5.6', '', 'c-123',
+    values = ('2015-05-16T10:24:28', 'mysql', '5.6', '5.7.29', '', 'c-123',
               'test_config', '2015-05-16T10:24:29', '{"max_connections": 5}')
 
     def setUp(self):
@@ -218,6 +219,7 @@ class TestConfigurationCreate(TestConfigurations):
             'created',
             'datastore_name',
             'datastore_version_name',
+            'datastore_version_number',
             'description',
             'id',
             'name',
@@ -229,7 +231,7 @@ class TestConfigurationCreate(TestConfigurations):
         args = ['c-123', '{"max_connections": 5}',
                 '--description', 'test_config',
                 '--datastore', 'mysql',
-                '--datastore_version', '5.6']
+                '--datastore-version', '5.6']
         parsed_args = self.check_parser(self.cmd, args, [])
         columns, data = self.cmd.take_action(parsed_args)
         self.assertEqual(self.columns, columns)
@@ -244,13 +246,14 @@ class TestConfigurationCreate(TestConfigurations):
             '{"param1": 1, "param2": 2}',
             description=None,
             datastore=None,
-            datastore_version=None)
+            datastore_version=None,
+            datastore_version_number=None)
 
     def test_configuration_create_with_optional_args(self):
         args = ['cgroup2', '{"param3": 3, "param4": 4}',
                 '--description', 'cgroup 2',
                 '--datastore', 'mysql',
-                '--datastore_version', '5.6']
+                '--datastore-version', '5.6']
         parsed_args = self.check_parser(self.cmd, args, [])
         self.cmd.take_action(parsed_args)
         self.configuration_client.create.assert_called_with(
@@ -258,7 +261,8 @@ class TestConfigurationCreate(TestConfigurations):
             '{"param3": 3, "param4": 4}',
             description='cgroup 2',
             datastore='mysql',
-            datastore_version='5.6')
+            datastore_version='5.6',
+            datastore_version_number=None)
 
 
 class TestConfigurationAttach(TestConfigurations):
