@@ -94,7 +94,7 @@ class Instances(base.ManagerWithFind):
                datastore=None, datastore_version=None, nics=None,
                configuration=None, replica_of=None, replica_count=None,
                modules=None, locality=None, region_name=None, access=None,
-               **kwargs):
+               datastore_version_number=None, **kwargs):
         """Create (boot) a new instance."""
 
         body = {"instance": {
@@ -117,6 +117,8 @@ class Instances(base.ManagerWithFind):
             datastore_obj["type"] = datastore
         if datastore_version:
             datastore_obj["version"] = datastore_version
+        if datastore_version_number:
+            datastore_obj["version_number"] = datastore_version_number
         if datastore_obj:
             body["instance"]["datastore"] = datastore_obj
         if nics:
@@ -149,11 +151,16 @@ class Instances(base.ManagerWithFind):
         resp, body = self.api.client.put(url, body=body)
         common.check_for_exceptions(resp, body, url)
 
-    def edit(self, instance, configuration=None, name=None,
-             detach_replica_source=False, remove_configuration=False):
+    def update(self, instance, configuration=None, name=None,
+               detach_replica_source=False, remove_configuration=False,
+               is_public=None, allowed_cidrs=None):
+        """Update instance.
+
+        The configuration change, detach_replica and access change cannot be
+        updated at the same time.
+        """
         body = {
-            "instance": {
-            }
+            "instance": {}
         }
         if configuration and remove_configuration:
             raise Exception("Cannot attach and detach configuration "
@@ -166,9 +173,15 @@ class Instances(base.ManagerWithFind):
             body["instance"]["name"] = name
         if detach_replica_source:
             body["instance"]["replica_of"] = None
+        if is_public is not None or allowed_cidrs is not None:
+            body["instance"]['access'] = {}
+            if is_public is not None:
+                body["instance"]['access']['is_public'] = is_public
+            if allowed_cidrs is not None:
+                body["instance"]['access']['allowed_cidrs'] = allowed_cidrs
 
         url = "/instances/%s" % base.getid(instance)
-        resp, body = self.api.client.patch(url, body=body)
+        resp, body = self.api.client.put(url, body=body)
         common.check_for_exceptions(resp, body, url)
 
     def upgrade(self, instance, datastore_version):
